=======
History
=======

0.3.1 (2019-03-06)
------------------

* Improved clarity with default values

0.3 (2019-03-06)
----------------

* Type annotations for `BlanketDB`
* Python 3.4 is not supported anymore (as it does not know type annotations)

0.2.2 (2019-01-31)
------------------

* setuptools entrypoint for cli
* quickstart documentation
* added logo

0.2.1 (2019-01-24)
------------------

* fix tag confusion

0.2.0 (2019-01-24)
------------------

* Added CLI for starting `BlanketDB` with `wsgiref.simple_server`
* Tests for `BlanketDB` Web API using `webtest`
* Added documentation for usage and Web API

0.1.0 (2019-01-18)
------------------

* First release on PyPI.
